@@ -23,7 +23,8 @@ class InstallLayer(tcl_ptc.BasePTCLayer):
 
         self.login()
         self.portal.portal_membership.getMemberById(
-            ptc.default_user).setProperties(fullname='Foo Full Name')
+            ptc.default_user).setProperties(
+            fullname=u'Foo Full N\xc3me') # test unicode
         self.folder.invokeFactory(
             type_name='Folder', id='slideshow', title='Slideshow')
         self.folder.slideshow.invokeFactory(
